using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using Leap;

public class LeapTouch {
	public Vector2 position;
	// the leap finger ID.
	public int fingerId;
	// the touch ID, which changes if the same finger untouches and then touches again.
	public int touchId;
	public TouchPhase phase;
}

public static class LeapInput {
	static int m_currentTouchId = 0;
	static Controller m_leapController = null;
	static List<LeapTouch> m_touches = new List<LeapTouch>();
	static public ReadOnlyCollection<LeapTouch> touches
	{
		get 
		{
			return new ReadOnlyCollection<LeapTouch>(m_touches);
		}
	}
	
	// updates the touch information. should be called every frame
	// from a gameobject in your scene.
	static public void ReadTouch() {
		if (m_leapController == null) {
			m_leapController = new Controller();
		}
		
		Frame frame = m_leapController.Frame();
		InteractionBox interactionBox = frame.InteractionBox;
		
		for(int i = 0; i < frame.Pointables.Count; ++i) {
			if (frame.Pointables[i].TouchZone != Pointable.Zone.ZONETOUCHING) continue;
			
			Vector3 normTipPosition = interactionBox.NormalizePoint(frame.Pointables[i].StabilizedTipPosition).ToUnity();
			Vector2 touchPosition = new Vector2(normTipPosition.x * UnityEngine.Screen.width, normTipPosition.y * UnityEngine.Screen.height);
			int fingerID = frame.Pointables[i].Id;
			
			LeapTouch touchItem = m_touches.Find(t => t.fingerId == fingerID);
			if (touchItem == null) {
				touchItem = new LeapTouch();
				touchItem.position = touchPosition;
				touchItem.fingerId = fingerID;
				touchItem.touchId = m_currentTouchId++;
				touchItem.phase = TouchPhase.Began;
				m_touches.Add(touchItem);
			} else {
				touchItem.phase = TouchPhase.Moved;
				touchItem.position = touchPosition;
				touchItem.fingerId = fingerID;
			}
		}
		
		// remove touches that have ids that do not exist in the pointables list.
		List<LeapTouch> newList = new List<LeapTouch>();
		for (int i = 0; i < m_touches.Count; ++i) {
			for (int j = 0; j < frame.Pointables.Count; ++j) {
				if (m_touches[i].fingerId == frame.Pointables[j].Id) {
					if (frame.Pointables[j].TouchZone == Pointable.Zone.ZONETOUCHING) {
						newList.Add(m_touches[i]);
						continue;
					}
				}
			}
		}
		
		m_touches = newList;
		
	}
	
}
